import os
import sys
from pdf2docx import Converter
import docx
import pandas as pd

def convert_pdf_to_docx(pdf_path, docx_path):
    cv = Converter(pdf_path)
    cv.convert(docx_path, start=0, end=None)
    cv.close()

def extract_tables_from_docx(docx_path, output_excel):
    doc = docx.Document(docx_path)
    tables = doc.tables

    if not tables:
        print("no-tables")
        return False

    with pd.ExcelWriter(output_excel) as writer:
        for i, table in enumerate(tables):
            data = []
            for row in table.rows:
                cells = []
                for cell in row.cells:
                    # Sometimes text is stored in paragraphs
                    paragraphs = [p.text.strip() for p in cell.paragraphs if p.text.strip()]
                    cells.append(" ".join(paragraphs) if paragraphs else "")
                data.append(cells)

            # Remove empty rows
            if all(all(cell == "" for cell in row) for row in data):
                continue

            df = pd.DataFrame(data)
            df.to_excel(writer, sheet_name=f"Table{i+1}", index=False)
    return True


def full_convert(pdf_path, output_excel):
    if not os.path.exists(pdf_path):
        print("pdf-not-found")
        return

    docx_temp = "/tmp/temp-convert.docx"
    convert_pdf_to_docx(pdf_path, docx_temp)
    
    if extract_tables_from_docx(docx_temp, output_excel):
        print("success")
    else:
        print("fail")

    # optional cleanup
    if os.path.exists(docx_temp):
        os.remove(docx_temp)

if __name__ == "__main__":
    if len(sys.argv) < 3:
        print("Usage: python pdf_to_excel_via_docx.py input.pdf output.xlsx")
    else:
        full_convert(sys.argv[1], sys.argv[2])
